==> qtjambi-qt3dlogic-5.15.14-sources.jar: io/qt/qt3d/logic/QFrameAction.java <==
package io.qt.qt3d.logic;

import io.qt.*;


/**
 * <p>Provides a way to have a synchronous function executed each frame</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qt3dlogic-qframeaction.html">Qt3DLogic::QFrameAction</a></p>
 */
public class QFrameAction extends io.qt.qt3d.core.QComponent
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QFrameAction.class);
    

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dlogic-qframeaction.html#triggered">Qt3DLogic::QFrameAction::triggered(float)</a></p>
     */
    public final @NonNull Signal1<java.lang.@QtPrimitiveType@NonNull Float> triggered = new Signal1<>();
    
    /**
     * <p>Overloaded constructor for {@link #(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QFrameAction() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dlogic-qframeaction.html#QFrameAction">Qt3DLogic::QFrameAction::QFrameAction(Qt3DCore::QNode*)</a></p>
     */
    @SuppressWarnings({"exports"})
    public QFrameAction(io.qt.qt3d.core.@Nullable QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QFrameAction instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @NativeAccess
    protected QFrameAction(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @NativeAccess
    protected QFrameAction(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @QtUninvokable
    private static native void initialize_native(QFrameAction instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-qt3dlogic-5.15.15-sources.jar: io/qt/qt3d/logic/QFrameAction.java <==
package io.qt.qt3d.logic;

import io.qt.*;


/**
 * <p>Provides a way to have a synchronous function executed each frame</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qt3dlogic-qframeaction.html">Qt3DLogic::QFrameAction</a></p>
 */
public class QFrameAction extends io.qt.qt3d.core.QComponent
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QFrameAction.class);
    

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dlogic-qframeaction.html#triggered">Qt3DLogic::QFrameAction::triggered(float)</a></p>
     */
    public final @NonNull Signal1<java.lang.@QtPrimitiveType@NonNull Float> triggered = new Signal1<>();
    
    /**
     * <p>Overloaded constructor for {@link #QFrameAction(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QFrameAction() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dlogic-qframeaction.html#QFrameAction">Qt3DLogic::QFrameAction::QFrameAction(Qt3DCore::QNode*)</a></p>
     */
    @SuppressWarnings({"exports"})
    public QFrameAction(io.qt.qt3d.core.@Nullable QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QFrameAction instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @NativeAccess
    protected QFrameAction(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @NativeAccess
    protected QFrameAction(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @QtUninvokable
    private static native void initialize_native(QFrameAction instance, QDeclarativeConstructor constructor);
    
}
